==> libKF5Kross-devel-5.12.0-1.tar.xz: usr/lib/cmake/KF5Kross/KF5KrossTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KrossCore" for configuration "RelWithDebInfo"
set_property(TARGET KF5::KrossCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5::KrossCore PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KrossCore.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Widgets;KF5::ConfigCore;KF5::I18n"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KrossCore-5.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KrossCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KrossCore "${_IMPORT_PREFIX}/lib/libKF5KrossCore.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KrossCore-5.dll" )

# Import target "KF5::KrossUi" for configuration "RelWithDebInfo"
set_property(TARGET KF5::KrossUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5::KrossUi PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KrossUi.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF5::I18n;KF5::IconThemes"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KrossUi-5.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KrossUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KrossUi "${_IMPORT_PREFIX}/lib/libKF5KrossUi.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KrossUi-5.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libKF5Kross-devel-5.39.0-1.tar.xz: usr/lib/cmake/KF5Kross/KF5KrossTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KrossCore" for configuration "RelWithDebInfo"
set_property(TARGET KF5::KrossCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5::KrossCore PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KrossCore.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Widgets;KF5::I18n"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KrossCore-5.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KrossCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KrossCore "${_IMPORT_PREFIX}/lib/libKF5KrossCore.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KrossCore-5.dll" )

# Import target "KF5::KrossUi" for configuration "RelWithDebInfo"
set_property(TARGET KF5::KrossUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5::KrossUi PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KrossUi.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF5::I18n;KF5::IconThemes"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KrossUi-5.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KrossUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KrossUi "${_IMPORT_PREFIX}/lib/libKF5KrossUi.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KrossUi-5.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
